Class: Megam::JSONCompat
- Inherits:
-
Object
- Object
- Megam::JSONCompat
- Defined in:
- lib/megam/core/json_compat.rb
Constant Summary collapse
- JSON_MAX_NESTING =
1000- JSON_CLAZ =
"json_claz".freeze
- MEGAM_AUTH =
"Megam::Auth".freeze
- MEGAM_ERROR =
"Megam::Error".freeze
- MEGAM_ACCOUNT =
"Megam::Account".freeze
- MEGAM_NODE =
"Megam::Node".freeze
- MEGAM_APPDEFNS =
"Megam::AppDefns".freeze
- MEGAM_APPREQS =
"Megam::AppRequest".freeze
- MEGAM_BOLTREQS =
"Megam::BoltRequest".freeze
- MEGAM_BOLTDEFNS =
"Megam::BoltDefns".freeze
- MEGAM_NODECOLLECTION =
"Megam::NodeCollection".freeze
- MEGAM_APPDEFNSCOLLECTION =
"Megam::AppDefnCollection".freeze
- MEGAM_APPREQSCOLLECTION =
"Megam::AppRequestCollection".freeze
- MEGAM_BOLTREQSCOLLECTION =
"Megam::BoltRequestCollection".freeze
- MEGAM_BOLTDEFNSCOLLECTION =
"Megam::BoltDefnCollection".freeze
- MEGAM_REQUEST =
"Megam::Request".freeze
- MEGAM_REQUESTCOLLECTION =
"Megam::RequestCollection".freeze
- MEGAM_PREDEF =
"Megam::Predef".freeze
- MEGAM_PREDEFCOLLECTION =
"Megam::PredefCollection".freeze
- MEGAM_PREDEFCLOUD =
"Megam::PredefCloud".freeze
- MEGAM_PREDEFCLOUDCOLLECTION =
"Megam::PredefCloudCollection".freeze
- MEGAM_CLOUDTOOL =
"Megam::CloudTool".freeze
- MEGAM_CLOUDTOOLCOLLECTION =
"Megam::CloudToolCollection".freeze
- MEGAM_CLOUDTEMPLATE =
"Megam::CloudTemplate".freeze
- MEGAM_CLOUDTEMPLATECOLLECTION =
"Megam::CloudTemplateCollection".freeze
- MEGAM_CLOUDINSTRUCTION =
"Megam::CloudInstruction".freeze
- MEGAM_CLOUDINSTRUCTIONCOLLECTION =
"Megam::CloudInstructionCollection".freeze
- MEGAM_CLOUDINSTRUCTIONGROUP =
"Megam::CloudInstructionGroup".freeze
Class Method Summary collapse
-
.class_for_json_class(json_class) ⇒ Object
Map
JSON_CLAZto a Class object. -
.from_json(source, opts = {}) ⇒ Object
Just call the JSON gem's parse method with a modified :max_nesting field.
- .map_hash_to_rb_obj(json_hash) ⇒ Object
-
.map_to_rb_obj(json_obj) ⇒ Object
Look at an object that's a basic type (from json parse) and convert it to an instance of Megam classes if desired.
-
.opts_add_max_nesting(opts) ⇒ Object
Increase the max nesting for JSON, which defaults to 19, and isn't enough for some (for example, a Node within a Node) structures.
- .to_json(obj, opts = nil) ⇒ Object
- .to_json_pretty(obj, opts = nil) ⇒ Object
Class Method Details
.class_for_json_class(json_class) ⇒ Object
Map JSON_CLAZ to a Class object. We use a case instead of a Hash
assigned to a constant because otherwise this file could not be loaded
until all the constants were defined, which means you'd have to load
the world to get json.
.from_json(source, opts = {}) ⇒ Object
Just call the JSON gem's parse method with a modified :max_nesting field
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/megam/core/json_compat.rb', line 65 def from_json(source, opts = {}) obj = ::Yajl::Parser.parse(source) # JSON gem requires top level object to be a Hash or Array (otherwise # you get the "must contain two octets" error). Yajl doesn't impose the # same limitation. For compatibility, we re-impose this condition. unless obj.kind_of?(Hash) or obj.kind_of?(Array) raise JSON::ParserError, "Top level JSON object must be a Hash or Array. (actual: #{obj.class})" end # The old default in the json gem (which we are mimicing because we # sadly rely on this misfeature) is to "create additions" i.e., convert # JSON objects into ruby objects. Explicit :create_additions => false # is required to turn it off. if opts[:create_additions].nil? || opts[:create_additions] map_to_rb_obj(obj) else obj end end |
.map_hash_to_rb_obj(json_hash) ⇒ Object
103 104 105 106 107 108 |
# File 'lib/megam/core/json_compat.rb', line 103 def map_hash_to_rb_obj(json_hash) json_hash.each do |key, value| json_hash[key] = map_to_rb_obj(value) end json_hash end |
.map_to_rb_obj(json_obj) ⇒ Object
Look at an object that's a basic type (from json parse) and convert it to an instance of Megam classes if desired.
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/megam/core/json_compat.rb', line 87 def map_to_rb_obj(json_obj) case json_obj when Hash mapped_hash = map_hash_to_rb_obj(json_obj) if json_obj.has_key?(JSON_CLAZ) && (class_to_inflate = class_for_json_class(json_obj[JSON_CLAZ])) class_to_inflate.json_create(mapped_hash) else mapped_hash end when Array json_obj.map {|e| map_to_rb_obj(e) } else json_obj end end |
.opts_add_max_nesting(opts) ⇒ Object
Increase the max nesting for JSON, which defaults to 19, and isn't enough for some (for example, a Node within a Node) structures.
56 57 58 59 60 61 62 |
# File 'lib/megam/core/json_compat.rb', line 56 def opts_add_max_nesting(opts) if opts.nil? || !opts.has_key?(:max_nesting) opts = opts.nil? ? Hash.new : opts.clone opts[:max_nesting] = JSON_MAX_NESTING end opts end |
.to_json(obj, opts = nil) ⇒ Object
110 111 112 |
# File 'lib/megam/core/json_compat.rb', line 110 def to_json(obj, opts = nil) obj.to_json(opts_add_max_nesting(opts)) end |
.to_json_pretty(obj, opts = nil) ⇒ Object
114 115 116 |
# File 'lib/megam/core/json_compat.rb', line 114 def to_json_pretty(obj, opts = nil) ::JSON.pretty_generate(obj, opts_add_max_nesting(opts)) end |